(function(){var AjentiOrgConnector;AjentiOrgConnector=(function(){function AjentiOrgConnector(){if(window.parent){this.target=window.parent;this.domainPolicy="*";this.enabled=true}}AjentiOrgConnector.prototype.send=function(event,data){var message;if(this.enabled){if(data==null){data={}}message={event:event,data:data};return this.target.postMessage(message,this.domainPolicy)}};AjentiOrgConnector.prototype.reportHeight=function(h){return this.send("height",h)};return AjentiOrgConnector})();$(function(){window.aoConnector=new AjentiOrgConnector();return window.aoConnector.send("ready")})}).call(this);