/*
Version: 3.2 Timestamp: Mon Sep 10 10:38:04 PDT 2012
*/

@image: "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADwAAAAoCAYAAACiu5n/AAACLElEQVR42u3Zz0sUYRzH8bUISoyF1i5iXSooyYgOEXapZNYNojwU/aAfUAT9A4YhUgdxt1To0KFIBCMIvEcUEXntUtivpYuUhYFIdDBMmD69he/hObgsbSnb13ngdZjZhX3eO8/MDrMpSctKErwsg//HUSgU7uNYsB3hHla4CybqEoRPaMJGFCEMewxuxnsIk5iALPqg1yVdj9eQGUdjiuE1eAs+QOYztrsMJqwFk8EyHguW95klD+ZD08gsYvBFCBPYgHXBOT1UNpg3ncQpnAicRbrCCQ3j8SIf5QvYEWxvxnlb0mWDr0MIvcOaCiayC78gRKmlH+WDbaIjkJnDzgq/+VHIvMWqag3ehBkIAxXGdkAIDVRlsE24H9//4ty9hju4Hej710c5m83WYging32HMYjMnwSvx75UlQ+iOiDEaEMLZiA8dPc7TFQDnkGYxQ8Iz9Hs8k4riqIa4l5ApojVbm8tiduPL5CZRs5lMGFH8DNYxo+C5d3tMfgohJeow0qMQujxuqRb0RBsZ3DA2ZIuP5LgJDgJToKr4ZHOWjTOy+fzNa6DiezCFGReod1lMGF3IYzjMm5B5rirYIJyEJ4iHezfjW+YRr2n4EHE2LrAa1cg5DwFj2DWLlKljn67p+B+CIdKPAaOsddTcBOEKbTZvjp0Qvjo8Sp9DjJFfIVMjBsef4f34AHeYAxX0VfqMbDnfw97IXMTta6DLbobcxBa3Qdb9BPE2LZQ8G98530ecQi/2QAAAABJRU5ErkJggg==";

.select2-container {
    position: relative;
    display: inline-block;
    /* inline-block for ie7 */
    zoom: 1;
    *display: inline;
    vertical-align: top;
}

.select2-container,
.select2-drop,
.select2-search,
.select2-search input{
    box-sizing: border-box;         /* css3 */
}

.select2-container .select2-choice {
    display: block;
    overflow: hidden;
    white-space: nowrap;
    position: relative;
    padding: 0 0 0 8px;
    color: #444;
    text-decoration: none;

    .control-inset();
    width: auto;
    border: 1px solid transparent;
}

.select2-container .select2-choice span {
    line-height: @controlHeight;
    margin-right: 26px;
    display: block;
    overflow: hidden;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
    -ms-text-overflow: ellipsis;
    text-overflow: ellipsis;
}

.select2-container .select2-choice abbr {
    display: block;
    position: absolute;
    right: 26px;
    top: 8px;
    width: 12px;
    height: 12px;
    font-size: 1px;
    //background: url(@image) right top no-repeat;
    cursor: pointer;
    text-decoration: none;
    border:0;
    outline: 0;
}
.select2-container .select2-choice abbr:hover {
    background-position: right -11px;
    cursor: pointer;
}

.select2-drop {
    background: #fff;
    color: #000;
    border: 1px solid #aaa;
    border-top: 0;
    position: absolute;
    top: 100%;
    .box-shadow(0 4px 5px rgba(0, 0, 0, .15));
    z-index: 9999;
    width: 100%;
    margin-top:-3px;
    margin-right: 1px;
    padding: 2px 0 0;
    .border-radius(0 0 4px 4px);
}
.select2-container .select2-choice div {
        position: absolute;
        right: 0;
        top: 0;
        display: block;
        height: 100%;
        width: 18px;
}

.select2-container .select2-choice div b {
        background: url(@image) no-repeat 0 1px;
        display: block;
        width: 100%;
        height: 100%;
}

.select2-search {
    display: inline-block;
        white-space: nowrap;
        z-index: 10000;
    min-height: 26px;
    width: 100%;
    margin: 0;
    padding-left: 4px;
    padding-right: 4px;
}

.select2-search-hidden {
    display: block;
    position: absolute;
    left: -10000px;
}

.select2-search input {
        background: #fff url(@image) no-repeat 100% -22px;
        background: url(@image) no-repeat 100% -22px, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, white), color-stop(0.99, #eeeeee));
        background: url(@image) no-repeat 100% -22px, -webkit-linear-gradient(center bottom, white 85%, #eeeeee 99%);
        background: url(@image) no-repeat 100% -22px, -moz-linear-gradient(center bottom, white 85%, #eeeeee 99%);
        background: url(@image) no-repeat 100% -22px, -o-linear-gradient(bottom, white 85%, #eeeeee 99%);
        background: url(@image) no-repeat 100% -22px, -ms-linear-gradient(top, #ffffff 85%, #eeeeee 99%);
        background: url(@image) no-repeat 100% -22px, linear-gradient(top, #ffffff 85%, #eeeeee 99%);
        padding: 4px 20px 4px 5px;
        outline: 0;
        border: 1px solid #aaa;
        font-family: sans-serif;
        font-size: 1em;
        width:100%;
        margin:0;
        height:auto !important;
        min-height: 26px;
        -webkit-box-shadow: none;
        -moz-box-shadow: none;
        box-shadow: none;
        border-radius: 0;
        -moz-border-radius: 0;
        -webkit-border-radius: 0;
}


.select2-container-active .select2-choice,
.select2-container-active .select2-choices {
    outline: none;
    border: 1px solid @orange;
}

.select2-dropdown-open .select2-choice {
    border: 1px solid #aaa;
    border-bottom: none;
    .box-shadow(0 1px 0 #fff inset);
    background-color: #fff;
    border-bottom-left-radius : 0;
    border-bottom-right-radius: 0;
}

.select2-dropdown-open .select2-choice div {
    background: transparent;
    border-left: none;
}
.select2-dropdown-open .select2-choice div b {
    background-position: -18px 1px;
}

/* results */
.select2-results {
    margin: 4px 4px 4px 0;
    padding: 0 0 0 4px;
    position: relative;
    overflow-x: hidden;
    overflow-y: auto;
    max-height: 200px;
}

.select2-results ul.select2-result-sub {
    margin: 0 0 0 0;
}

.select2-results ul.select2-result-sub > li .select2-result-label { padding-left: 20px }
.select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 40px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 60px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 80px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 100px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 110px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 120px }

.select2-results li {
    list-style: none;
    display: list-item;
}

.select2-results li.select2-result-with-children > .select2-result-label {
    font-weight: bold;
}

.select2-results .select2-result-label {
    padding: 3px 7px 4px;
    margin: 0;
    cursor: pointer;
}

.select2-results .select2-highlighted {
    background: @orange;
    color: #fff;
}
.select2-results li em {
    background: #feffde;
    font-style: normal;
}
.select2-results .select2-highlighted em {
    background: transparent;
}
.select2-results .select2-no-results,
.select2-results .select2-searching,
.select2-results .select2-selection-limit {
    display: list-item;
    width: 100%;
    text-align: center;
    padding: 5px 10px;
}

/*
disabled look for already selected choices in the results dropdown
.select2-results .select2-disabled.select2-highlighted {
        color: #666;
        background: #f4f4f4;
        display: list-item;
        cursor: default;
}
.select2-results .select2-disabled {
    background: #f4f4f4;
    display: list-item;
    cursor: default;
}
*/
.select2-results .select2-disabled {
        display: none;
}

.select2-more-results {
    background: #f4f4f4;
    display: list-item;
}

/* disabled styles */

.select2-container.select2-container-disabled .select2-choice {
        background-color: #f4f4f4;
        background-image: none;
        border: 1px solid #ddd;
        cursor: default;
}

.select2-container.select2-container-disabled .select2-choice div {
        background-color: #f4f4f4;
        background-image: none;
        border-left: 0;
}


/* multiselect */

.select2-container-multi .select2-choices {
        background-color: #fff;
            background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, color-stop(1%, #eeeeee), color-stop(15%, #ffffff));
            background-image: -webkit-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
            background-image: -moz-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
            background-image: -o-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
            background-image: -ms-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
            background-image: linear-gradient(top, #eeeeee 1%, #ffffff 15%);
            border: 1px solid #aaa;
            margin: 0;
            padding: 0;
            cursor: text;
            overflow: hidden;
            height: auto !important;
            height: 1%;
            position: relative;
}

.select2-container-multi .select2-choices {
        min-height: 26px;
}

.select2-container-multi.select2-container-active .select2-choices {
    -webkit-box-shadow: 0 0 5px rgba(0,0,0,.3);
    -moz-box-shadow   : 0 0 5px rgba(0,0,0,.3);
    -o-box-shadow     : 0 0 5px rgba(0,0,0,.3);
    box-shadow        : 0 0 5px rgba(0,0,0,.3);
    border: 1px solid #5897fb;
    outline: none;
}
.select2-container-multi .select2-choices li {
    float: left;
    list-style: none;
}
.select2-container-multi .select2-choices .select2-search-field {
    white-space: nowrap;
    margin: 0;
    padding: 0;
}

.select2-container-multi .select2-choices .select2-search-field input {
    color: #666;
    background: transparent !important;
    font-family: sans-serif;
    font-size: 100%;
    height: 15px;
    padding: 5px;
    margin: 1px 0;
    outline: 0;
    border: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow   : none;
    -o-box-shadow     : none;
    box-shadow        : none;
}

.select2-default {
    color: #999 !important;
}

.select2-container-multi .select2-choices .select2-search-choice {
    -webkit-border-radius: 3px;
    -moz-border-radius   : 3px;
    border-radius        : 3px;
    -moz-background-clip   : padding;
    -webkit-background-clip: padding-box;
    background-clip        : padding-box;
    background-color: #e4e4e4;
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f4f4f4', endColorstr='#eeeeee', GradientType=0 );
    background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, color-stop(20%, #f4f4f4), color-stop(50%, #f0f0f0), color-stop(52%, #e8e8e8), color-stop(100%, #eeeeee));
    background-image: -webkit-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    background-image: -moz-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    background-image: -o-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    background-image: -ms-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    background-image: linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    -webkit-box-shadow: 0 0 2px #ffffff inset, 0 1px 0 rgba(0,0,0,0.05);
    -moz-box-shadow   : 0 0 2px #ffffff inset, 0 1px 0 rgba(0,0,0,0.05);
    box-shadow        : 0 0 2px #ffffff inset, 0 1px 0 rgba(0,0,0,0.05);
    color: #333;
    border: 1px solid #aaaaaa;
    line-height: 13px;
    padding: 3px 5px 3px 18px;
    margin: 3px 0 3px 5px;
    position: relative;
    cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice span {
    cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice-focus {
    background: #d4d4d4;
}

.select2-search-choice-close {
    display: block;
    position: absolute;
    right: 3px;
    top: 4px;
    width: 12px;
    height: 13px;
    font-size: 1px;
    background: url(@image) right top no-repeat;
    outline: none;
}

.select2-container-multi .select2-search-choice-close {
    left: 3px;
}


.select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close:hover {
    background-position: right -11px;
}
.select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close {
    background-position: right -11px;
}

/* disabled styles */

.select2-container-multi.select2-container-disabled .select2-choices{
        background-color: #f4f4f4;
        background-image: none;
        border: 1px solid #ddd;
        cursor: default;
}

.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice {
        background-image: none;
        background-color: #f4f4f4;
        border: 1px solid #ddd;
        padding: 3px 5px 3px 5px;
}

.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close {
        display: none;
}
/* end multiselect */

.select2-result-selectable .select2-match,
.select2-result-unselectable .select2-result-selectable .select2-match { text-decoration: underline; }
.select2-result-unselectable .select2-match { text-decoration: none; }

.select2-offscreen { position: absolute; left: -10000px; }

/* Retina-ize icons */

@media only screen and (-webkit-min-device-pixel-ratio: 1.5) {
        .select2-search input, .select2-search-choice-close, .select2-container .select2-choice abbr, .select2-container .select2-choice div b {
                background-image: url(select2x2.png) !important;
                background-repeat: no-repeat !important;
                background-size: 60px 40px !important;
        }
        .select2-search input {
                background-position: 100% -21px !important;
        }
}